==> geopsypack-src-3.3.6.tar.gz: geopsypack-src-3.3.6/geopsy/src/SignalTableItem.h <==
/***************************************************************************
**
**  This file is part of geopsy.
**
**  geopsy is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  geopsy is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2006-05-03
**  Copyright: 2006-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef SIGNALTABLEITEM_H
#define SIGNALTABLEITEM_H

#include <QAbstractItemModel>

#include <GeopsyCore.h>

class SignalTableItem : public QAbstractItemModel
{
  Q_OBJECT
public:
  SignalTableItem(const SubSignalPool * subPool, QObject * parent=nullptr);
  ~SignalTableItem();

  virtual int rowCount(const QModelIndex &parent=QModelIndex()) const;
  virtual int columnCount(const QModelIndex &parent=QModelIndex()) const;
  virtual QVariant data(const QModelIndex &index, int role) const;
  virtual QVariant headerData(int section, Qt::Orientation orientation, int role=Qt::DisplayRole) const;
  virtual QModelIndex parent (const QModelIndex & index) const;
  virtual QModelIndex index (int, int column, const QModelIndex & parent=QModelIndex()) const;
  virtual bool setData (const QModelIndex & index, const QVariant & value, int role=Qt::EditRole);
  virtual Qt::ItemFlags flags (const QModelIndex & ) const {return Qt::ItemIsSelectable | Qt::ItemIsEditable | Qt::ItemIsEnabled;}

  const MetaDataIndex& dataIndex(int column) const {return _dataFields.at(column);}
  MetaDataFieldList& dataFields() {return _dataFields;}
  const SubSignalPool * subPool() const {return _subPool;}
  SignalDatabase * database() const {return _subPool->database();}
public slots:
  void beginChange();
  void endChange();
private:
  const SubSignalPool * _subPool;
  MetaDataFieldList _dataFields;
};

#endif // SIGNALTABLEITEM_H

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/geopsy/src/SignalTableItem.h <==
/***************************************************************************
**
**  This file is part of geopsy.
**
**  geopsy is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  geopsy is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2006-05-03
**  Copyright: 2006-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef SIGNALTABLEITEM_H
#define SIGNALTABLEITEM_H

#include <QAbstractItemModel>

#include <GeopsyCore.h>

class SignalTableItem : public QAbstractItemModel
{
  Q_OBJECT
public:
  SignalTableItem(const SubSignalPool * subPool, QObject * parent=nullptr);
  ~SignalTableItem();

  int rowCount(const QModelIndex &parent=QModelIndex()) const;
  int columnCount(const QModelIndex &parent=QModelIndex()) const;
  QVariant data(const QModelIndex &index, int role) const;
  QVariant headerData(int section, Qt::Orientation orientation, int role=Qt::DisplayRole) const;
  QModelIndex parent (const QModelIndex & index) const;
  QModelIndex index (int, int column, const QModelIndex & parent=QModelIndex()) const;
  bool setData (const QModelIndex & index, const QVariant & value, int role=Qt::EditRole);
  Qt::ItemFlags flags (const QModelIndex & ) const {return Qt::ItemIsSelectable | Qt::ItemIsEditable | Qt::ItemIsEnabled;}

  const MetaDataIndex& dataIndex(int column) const {return _dataFields.at(column);}
  MetaDataFieldList& dataFields() {return _dataFields;}
  const SubSignalPool * subPool() const {return _subPool;}
  SignalDatabase * database() const {return _subPool->database();}
public slots:
  void beginChange();
  void endChange();
private:
  const SubSignalPool * _subPool;
  MetaDataFieldList _dataFields;
};

#endif // SIGNALTABLEITEM_H
